Estimation
==========

Signal-to-noise ratio
---------------------

.. python-apigen-group:: estimation-snr

Time domain
-----------

.. python-apigen-group:: estimation-time

Frequency domain
----------------

.. python-apigen-group:: estimation-frequency
